ConnectivityInfo class
Detailed connectivity information
Constructors
-
ConnectivityInfo({required ConnectivityStatus status, required List<
ConnectivityResult> types, required bool hasInternet, required DateTime timestamp, Duration? latency, ConnectionQuality quality = ConnectionQuality.unknown}) -
const
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- hasInternet → bool
-
final
- isChecking → bool
-
no setter
- isEthernet → bool
-
no setter
- isMobile → bool
-
no setter
- isOffline → bool
-
no setter
- isOnline → bool
-
no setter
- isWifi → bool
-
no setter
- latency → Duration?
-
final
- quality → ConnectionQuality
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- status → ConnectivityStatus
-
final
- timestamp → DateTime
-
final
-
types
→ List<
ConnectivityResult> -
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited